Modeling Judgments of Frequency with MINERVA 2
MINERVA2(x, y, ..., sqc, L, dec = NULL)input handled by MINERVA 2. Values -1, 0 and 1 are allowed. -1 represents the absence of a feature, 0 the irrelevance of a feature and 1 the presence of a feature.
another input handled by MINERVA 2. At least two inputs are needed for the simulation.
other inputs for modeling.
sequence of the different objects. Each input gets
an ascending number. x gets the value 1,
y gets the value 2, ... gets the value
3 and so on.
The argument sqc = c(1, 2, 3, 2) means: first
input x is processed, second input y is
processed followed by processing input number three and
fourth, th input y is used again.
So sqc contains the frequency information too.
In c(1, 2, 3, 2), x and the third input
are presented once. The input y is presented twice.
learning parameter. This is the proportion of a
correctly stored vector. L = 1 means 100 % of the input
is processed correctly. If L is a vector, each input
could be handled differently. So L = c(.5, .6, .9) means,
input x is correctly stored to 50 %, input
y is stored to 60 % and the third input (inserted
in ...) is stored with 90 % probability.
decay is not part of the original version of MINERVA 2.
This is just implemented for a better comparison with the other
models of JoF. In dec = NULL, decay has no effect.
For dec = 'curve' decay uses a forgetting curve.
If dec is a numeric Vector e. g. dec = c(.8, .9, 1)
the memory traces are weighted. The first represented trace is
weighted by .8 the second by .9 and the youngest trace by 1.
The value dec = 1 corresponds with the original model.
MINERVA2 returns the relative judgment of frequency
Calculations of MINERVA 2 contain four steps. $$S_{i} = \frac{\sum_{j=1}^{N}{P_{j}T_{ij}}}{N_{i}}$$ $$A_{i} = S_{i}^{3}$$ $$I = \sum_{i=1}^{M}{A_{i}}$$ $$relative JoF = \frac{I_{j}}{\sum_{j}^{K}{I_{j}}}$$
Dougherty, M. R., Gettys, C. F., & Ogden, E. E. (1999). MINERVA-DM: A memory processes model for judgments of likelihood. Psychological Review, 106(1), 180.
Hintzman, D. L. (1984). MINERVA 2: A simulation model of human memory. Behavior Research Methods, Instruments, and Computers, 16, 96<U+2013>101.
# NOT RUN {
#This example is presented in Dougherty,
#Gettys, & Ogden, 1999 (p. 185)
H1 <- c(-1, 1, 0, 1, 0, -1, 1, -1, 0)
H2 <- c(-1, 0, 0, 1, 0, 0, 1, 0, 0)
x <- MINERVA2(H1, H2, sqc = c(2, 1), L = 1)
# }
Run the code above in your browser using DataLab